Alias for typos of `tqdm <https://github.com/tqdm/tqdm>`_.

It's tqdm, *taqaddum*, *te quiero demasiado*!

If you don't like it... have a meta comic: `xkcd#302 <https://xkcd.com/302/>`_.

Also see `tqdm#995 <https://github.com/tqdm/tqdm/issues/995>`_.
